function INTRO(DURATION, DURATION_SHOW, FG, BG, W,H,BORDER)
	DURATION = DURATION or 3
	DURATION_SHOW = DURATION_SHOW or .7
	FG = FG or {184,139,88}
	BG = BG or {38,36,26}
	W, H, BORDER = W or 15, H or 15, BORDER or 3

	math.randomseed(os.time())

	-- ANIMATION
	local board = {
		{1,0,1,0,1,1,0,1,0,0,1,1,0},
		{1,0,1,0,1,0,0,1,0,0,1,0,1},
		{0,1,0,0,1,0,0,1,1,0,1,1,0},
	}

	local sequence = {i = 1, t = 0}
	for i = 1,#board do
		for k = 1,#board[i] do
			sequence[#sequence+1] = {dt = .1 + math.random() * .9, y = i, x = k}
			if board[i][k] == 0 then
				sequence[#sequence+1] = {dt = .1 + math.random() * .9, y = i, x = k}
			end
			board[i][k] = {a = 0, da = 0}
		end
	end


	-- GRAPHICS
	local offset = {
		x = (love.graphics.getWidth() - #board[1] * (BORDER + W)) / 2,
		y = (love.graphics.getHeight() - #board   * (BORDER + H)) / 2,
	}
	local haze = love.graphics.newImage('haze.png')
	haze = {
		img = haze,
		sx = love.graphics.getWidth() / haze:getWidth(),
		sy = love.graphics.getHeight() / haze:getHeight(),
	}

	-- SOUND
	local sources = {}
	local woosh = love.sound.newSoundData('woosh.ogg')
	local woosh_length = woosh:getSize() / woosh:getBits() * 8 / woosh:getSampleRate()
	woosh = love.audio.newSource(woosh)

	local tick = love.sound.newSoundData(.1 * 44100, 44100, 16, 1)
	for i = 0,.1*44100 do
		local t = i / 44100
		local sample = math.sin(t * 440 * math.pi * 2) * .1
		if t > .03 then
			sample = sample + tick:getSample(i - .03 * 44100) * .4
		end
		if t > .06 then
			sample = sample + tick:getSample(i - .06 * 44100) * .2
		end
		sample = sample * (1 - t/.1)
		tick:setSample(i, sample)
	end


	-- TIME NORMALIZATION
	for i = 1,#sequence do
		local k = math.random(i,#sequence)
		sequence[i], sequence[k] = sequence[k], sequence[i]
		sequence[i].dt = sequence[i].dt / #sequence * (DURATION - woosh_length - DURATION_SHOW)
	end


	-- LOGIC
	local draw = love.draw or function() end
	local update = love.update or function() end
	local keypressed = love.keypressed or function() end
	local bg = {love.graphics.getBackgroundColor()}
	local fg = {love.graphics.getColor()}
	love.graphics.setBackgroundColor(BG)

	local function exit()
		love.graphics.setBackgroundColor(bg)
		love.graphics.setColor(fg)
		love.draw = draw
		love.update = update
		love.keypressed = keypressed
	end

	local function update_common(dt)
		-- update board alpha
		for i = 1,#board do
			for k = 1,#board[i] do
				local cell = board[i][k]
				cell.a = math.max(math.min(cell.a + 15 * cell.da * dt * 255, 255), 0)
			end
		end

		-- update sound
		for i = #sources,1,-1 do
			if sources[i]:isStopped() then
				table.remove(sources, i)
			end
		end
	end

	local function vrld_out()
		woosh:play()
		local draw = love.draw
		BG[4] = 4
		local t, s = 0, 0
		love.keypressed = function() end

		function love.update(dt)
			if woosh:isStopped() then return exit() end
			t = t + dt
			s = t / woosh_length
			BG[4] = math.min(math.sqrt(s) * 2 * 255, 255)
			update_common(dt)
		end

		function love.draw()
			draw()
			love.graphics.setColor(BG)
			love.graphics.draw(haze.img, love.graphics.getWidth(),0,0, -haze.sx * math.sqrt(s) * 2, haze.sy * math.sqrt(s) * 5)
		end
	end

	local t = 0
	local function vrld_show(dt)
		t = t + dt
		if t > DURATION_SHOW then vrld_out() end
		update_common(dt)
	end

	local function vrld_in(dt)
		dt = math.min(dt, 1 / 25)

		-- update sequence/state switch
		if sequence[sequence.i] then
			if sequence.t >= sequence[sequence.i].dt then
				local s = sequence[sequence.i]
				if board[s.y][s.x].da == 0 then
					board[s.y][s.x].da = 1
				else
					board[s.y][s.x].da = -board[s.y][s.x].da
				end

				local src = love.audio.newSource(tick)
				src:play()
				sources[#sources+1] = src

				sequence.t = sequence.t - sequence[sequence.i].dt
				sequence.i = sequence.i + 1
			end
			sequence.t = sequence.t + dt
		else
			love.update = vrld_show
		end
		update_common(dt)
	end

	love.update = vrld_in
	love.keypressed = vrld_out

	function love.draw()
		for i = 1,#board do
			local y = offset.y + (i-1) * (H + BORDER)
			for k = 1,#board[1] do
				if board[i][k].a ~= 0 then
					FG[4] = board[i][k].a
					love.graphics.setColor(FG)
					local x = offset.x + (k-1) * (W + BORDER)
					love.graphics.rectangle('fill', x,y, W, H)
				end
			end
		end
	end
end

function love.load()
	love.graphics.setBackgroundColor(38,36,26)
	INTRO(3)
	bigfont = love.graphics.newFont(70)
	smallfont = love.graphics.newFont(10)
end

function love.keypressed()
	love.event.push('q')
end

function love.draw()
	love.graphics.setColor(184,139,88)
	love.graphics.setFont(bigfont)
	local x = (love.graphics.getWidth() - bigfont:getWidth('THE GAME')) / 2
	local y = (love.graphics.getHeight() - bigfont:getHeight('THE GAME')) / 2
	love.graphics.print('THE GAME', x,y)

	love.graphics.setColor(184,139,88,30)
	love.graphics.setFont(smallfont)
	love.graphics.print('you lost', x,y - smallfont:getHeight('you lost'))
end
